Animo-Trainer uses the ML-Agents Reinforcement Learning Toolkit to train intelligent agents. It is a part of the Little Learning Machines game. https://store.steampowered.com/app/1993710/Little_Learning_Machines/

Dependencies: (Windows)
1. PyTorch depends on Microsoft Visual C++ Redistibutable: https://aka.ms/vs/16/release/vc_redist.x64.exe
2. Animo Simulation depends on DotNet Runtime 7: https://dotnet.microsoft.com/en-us/download/dotnet/7.0